@@ -1,6 +1,6 @@
 from dateutil.parser import isoparse
 
-from hcloud.core.domain import BaseDomain, DomainIdentityMixin
+from ..core.domain import BaseDomain, DomainIdentityMixin
 
 
 class Volume(BaseDomain, DomainIdentityMixin):
