@@ -1,11 +1,13 @@
 from unittest import mock
+
 import pytest
+
 from hcloud import Client
 
 
 @pytest.fixture(autouse=True, scope="function")
 def mocked_requests():
-    patcher = mock.patch("hcloud.hcloud.requests")
+    patcher = mock.patch("hcloud._client.requests")
     mocked_requests = patcher.start()
     yield mocked_requests
     patcher.stop()
