@@ -1,15 +1,16 @@
-import pytest
-from unittest import mock
 import datetime
-from dateutil.tz import tzoffset
+from datetime import timezone
+from unittest import mock
+
+import pytest
 
-from hcloud.images.client import ImagesClient, BoundImage
 from hcloud.actions.client import BoundAction
+from hcloud.images.client import BoundImage, ImagesClient
 from hcloud.images.domain import Image
 from hcloud.servers.client import BoundServer
 
 
-class TestBoundImage(object):
+class TestBoundImage:
     @pytest.fixture()
     def bound_image(self, hetzner_client):
         return BoundImage(client=hetzner_client.images, data=dict(id=14))
@@ -25,13 +26,14 @@ class TestBoundImage(object):
         assert bound_image.image_size == 2.3
         assert bound_image.disk_size == 10
         assert bound_image.created == datetime.datetime(
-            2016, 1, 30, 23, 50, tzinfo=tzoffset(None, 0)
+            2016, 1, 30, 23, 50, tzinfo=timezone.utc
         )
         assert bound_image.os_flavor == "ubuntu"
         assert bound_image.os_version == "16.04"
+        assert bound_image.architecture == "x86"
         assert bound_image.rapid_deploy is False
         assert bound_image.deprecated == datetime.datetime(
-            2018, 2, 28, 0, 0, tzinfo=tzoffset(None, 0)
+            2018, 2, 28, 0, 0, tzinfo=timezone.utc
         )
 
         assert isinstance(bound_image.created_from, BoundServer)
@@ -119,7 +121,7 @@ class TestBoundImage(object):
         assert action.progress == 0
 
 
-class TestImagesClient(object):
+class TestImagesClient:
     @pytest.fixture()
     def images_client(self):
         return ImagesClient(client=mock.MagicMock())
@@ -223,6 +225,21 @@ class TestImagesClient(object):
         assert image.id == 4711
         assert image.name == "ubuntu-20.04"
 
+    def test_get_by_name_and_architecture(self, images_client, one_images_response):
+        images_client._client.request.return_value = one_images_response
+        image = images_client.get_by_name_and_architecture("ubuntu-20.04", "x86")
+
+        params = {"name": "ubuntu-20.04", "architecture": ["x86"]}
+
+        images_client._client.request.assert_called_with(
+            url="/images", method="GET", params=params
+        )
+
+        assert image._client is images_client
+        assert image.id == 4711
+        assert image.name == "ubuntu-20.04"
+        assert image.architecture == "x86"
+
     @pytest.mark.parametrize(
         "image", [Image(id=1), BoundImage(mock.MagicMock(), dict(id=1))]
     )
