@@ -1,12 +1,13 @@
-import pytest
-from unittest import mock
 import datetime
-from dateutil.tz import tzoffset
+from datetime import timezone
+from unittest import mock
 
-from hcloud.isos.client import IsosClient, BoundIso
+import pytest
+
+from hcloud.isos.client import BoundIso, IsosClient
 
 
-class TestBoundIso(object):
+class TestBoundIso:
     @pytest.fixture()
     def bound_iso(self, hetzner_client):
         return BoundIso(client=hetzner_client.isos, data=dict(id=14))
@@ -18,12 +19,13 @@ class TestBoundIso(object):
         assert bound_iso.name == "FreeBSD-11.0-RELEASE-amd64-dvd1"
         assert bound_iso.description == "FreeBSD 11.0 x64"
         assert bound_iso.type == "public"
+        assert bound_iso.architecture == "x86"
         assert bound_iso.deprecated == datetime.datetime(
-            2018, 2, 28, 0, 0, tzinfo=tzoffset(None, 0)
+            2018, 2, 28, 0, 0, tzinfo=timezone.utc
         )
 
 
-class TestIsosClient(object):
+class TestIsosClient:
     @pytest.fixture()
     def isos_client(self):
         return IsosClient(client=mock.MagicMock())
