@@ -1,26 +1,25 @@
 from unittest import mock
+
 import pytest
 
+from hcloud.actions.client import BoundAction
 from hcloud.load_balancer_types.domain import LoadBalancerType
-from hcloud.locations.domain import Location
-from hcloud.networks.domain import Network
-from hcloud.servers.domain import Server
-
 from hcloud.load_balancers.client import BoundLoadBalancer, LoadBalancersClient
-
 from hcloud.load_balancers.domain import (
+    LoadBalancer,
     LoadBalancerAlgorithm,
     LoadBalancerHealthCheck,
     LoadBalancerService,
     LoadBalancerTarget,
-    LoadBalancer,
     LoadBalancerTargetIP,
     LoadBalancerTargetLabelSelector,
 )
-from hcloud.actions.client import BoundAction
+from hcloud.locations.domain import Location
+from hcloud.networks.domain import Network
+from hcloud.servers.domain import Server
 
 
-class TestBoundLoadBalancer(object):
+class TestBoundLoadBalancer:
     @pytest.fixture()
     def bound_load_balancer(self, hetzner_client):
         return BoundLoadBalancer(client=hetzner_client.load_balancers, data=dict(id=14))
@@ -350,7 +349,7 @@ class TestBoundLoadBalancer(object):
         assert action.progress == 0
 
 
-class TestLoadBalancerslient(object):
+class TestLoadBalancerslient:
     @pytest.fixture()
     def load_balancers_client(self):
         return LoadBalancersClient(client=mock.MagicMock())
